@@ -5,11 +5,8 @@
 #include "htslib/vcf.h"
 #include "htslib/khash.h"
 
-int hts_useek(htsFile *fp, long uoffset, int where);
-long hts_utell(htsFile *fp);
-
 int hts_set_verbosity(int verbosity);
-int hts_get_verbosity();
+int hts_get_verbosity(void);
 
 
 KHASH_MAP_INIT_STR(vdict, bcf_idinfo_t)
@@ -18,20 +15,6 @@ typedef khash_t(vdict) vdict_t;
 KHASH_DECLARE(s2i, kh_cstr_t, int64_t)
 typedef khash_t(s2i) s2i_t;
 		     
-//////////////////////////////////////////////////////////////////
-/*! set pysam standard error to point to file descriptor
-
-  Setting the stderr will close the previous stderr.
- */
-// FILE * pysam_set_stderr(int fd);
-
-//////////////////////////////////////////////////////////////////
-/*! set pysam standard error to /dev/null.
-  
-  Unsetting the stderr will close the previous stderr.
- */
-// void pysam_unset_stderr();
-
 //////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////
@@ -95,15 +78,13 @@ static inline char pysam_bam_seqi(uint8_t * s, int i) {
 static inline uint8_t pysam_get_qual(bam1_t * b) {
   return b->core.qual;}
 
-
-static inline uint16_t pysam_get_n_cigar(bam1_t * b) {
+static inline uint32_t pysam_get_n_cigar(bam1_t * b) {
   return b->core.n_cigar;}
 
 static inline void pysam_set_qual(bam1_t * b, uint8_t v) {
   b->core.qual=v;}
 
-
-static inline void pysam_set_n_cigar(bam1_t * b, uint16_t v) {
+static inline void pysam_set_n_cigar(bam1_t * b, uint32_t v) {
   b->core.n_cigar=v;}
 
 static inline void pysam_update_flag(bam1_t * b, uint16_t v, uint16_t flag) {
@@ -113,5 +94,4 @@ static inline void pysam_update_flag(bam1_t * b, uint16_t v, uint16_t flag) {
     b->core.flag &= ~flag;
 }
 
-  
 #endif
